==> schemar-0.0.9.tgz: package/test/api.js <==
var schemar= require('../');
var Datas= require('./datas');
var Layouts= require('./layouts');
var jsome= require('jsome');
var _= require('lodash')
/*
jsome(schemar.parse(Datas.varies, { textThres: 20 }));
jsome(schemar.parse(Datas.nested, { textThres: 20 }));
jsome(schemar.jsonSchema(Datas.jeremy, Layouts.jeremy));
jsome(schemar.jsonSchema(Datas.joe, { textThres: 20, title: 'sparta!!' }));
jsome(schemar.jsonSchema(Datas.resume, { textThres: 20, title: 'sparta!!' }));
jsome(schemar.jsonSchema(Datas.strata, { textThres: 20, title: 'sparta!!' }));
jsome(schemar.parseObj(Datas.resume, { textThres: 20 }))*/
//console.log(JSON.stringify(schemar.jsonSchema(Datas.strata), null, 4));
var fs= require('fs');
var json= JSON.parse(fs.readFileSync('./canner.json', 'utf8'));
var schema= schemar.parseObj(json.data, { textThres: 20 });
jsome(schema)
mergeInto(schema, json.columns)
jsome(schema);
function mergeInto (schema, cols) {
	for(key in cols){
		var settings= cols[key];
		var keyInfo= schema[key];

		// if key in columns not defined in schema
		if(!keyInfo) continue;

		// only description
		if(_.isString(settings)){
			settings= {'description': settings};
		}
		

		// if it's an array
		if(_.isArray(keyInfo)){
			for(key in settings){
				var setting= settings[key];
				
				// if a pure value object in array
				if(_.isString(setting)){
					if(key=='format' || key=='description')
						keyInfo[0][key]= setting;
				}

				// if a nested object in array
				mergeInto(keyInfo[0], settings);
			}
		}else if(_.isPlainObject(settings)){
			// an object with description, format
			for(key in settings){
				var setting= settings[key];

				// if setting is key/value
				// it's either a format, description object
				// or a nested array/object description
				if(_.isString(setting)){
					if(key=='format' || key=='description')
						keyInfo[key]= setting;
				}

				// if nested
				if (_.isPlainObject(setting))
					mergeInto(keyInfo[key], setting);
			}
		}
			
	}
}

==> schemar-0.0.10.tgz: package/test/api.js <==
var schemar= require('../');
var Datas= require('./datas');
var Layouts= require('./layouts');
var jsome= require('jsome');
var _= require('lodash')
/*
jsome(schemar.parse(Datas.varies, { textThres: 20 }));
jsome(schemar.parse(Datas.nested, { textThres: 20 }));
jsome(schemar.jsonSchema(Datas.jeremy, Layouts.jeremy));
jsome(schemar.jsonSchema(Datas.joe, { textThres: 20, title: 'sparta!!' }));
jsome(schemar.jsonSchema(Datas.resume, { textThres: 20, title: 'sparta!!' }));
jsome(schemar.jsonSchema(Datas.strata, { textThres: 20, title: 'sparta!!' }));
jsome(schemar.parseObj(Datas.resume, { textThres: 20 }))*/
//console.log(JSON.stringify(schemar.jsonSchema(Datas.strata), null, 4));
var fs= require('fs');
var json= JSON.parse(fs.readFileSync('./canner.json', 'utf8'));
var schema= schemar.parseObj(json.data, { textThres: 20 });
jsome(schema)
//mergeInto(schema, json.columns)
//jsome(schema);
function mergeInto (schema, cols) {
	for(key in cols){
		var settings= cols[key];
		var keyInfo= schema[key];

		// if key in columns not defined in schema
		if(!keyInfo) continue;

		// only description
		if(_.isString(settings)){
			settings= {'description': settings};
		}
		

		// if it's an array
		if(_.isArray(keyInfo)){
			for(key in settings){
				var setting= settings[key];
				
				// if a pure value object in array
				if(_.isString(setting)){
					if(key=='format' || key=='description')
						keyInfo[0][key]= setting;
				}

				// if a nested object in array
				mergeInto(keyInfo[0], settings);
			}
		}else if(_.isPlainObject(settings)){
			// an object with description, format
			for(key in settings){
				var setting= settings[key];

				// if setting is key/value
				// it's either a format, description object
				// or a nested array/object description
				if(_.isString(setting)){
					if(key=='format' || key=='description')
						keyInfo[key]= setting;
				}

				// if nested
				if (_.isPlainObject(setting))
					mergeInto(keyInfo[key], setting);
			}
		}
			
	}
}
